@@ -14,16 +14,13 @@
  * limitations under the License.
  */
 
+#include "bson-prelude.h"
+
 
 #ifndef BSON_MACROS_H
 #define BSON_MACROS_H
 
 
-#if !defined(BSON_INSIDE) && !defined(BSON_COMPILATION)
-#error "Only <bson.h> can be included directly."
-#endif
-
-
 #include <stdio.h>
 
 #ifdef __cplusplus
@@ -179,7 +176,7 @@
 #define bson_str_empty0(s) (!s || !s[0])
 
 
-#if defined(_WIN32)
+#if defined(_MSC_VER)
 #define BSON_FUNC __FUNCTION__
 #elif defined(__STDC_VERSION__) && __STDC_VERSION__ < 199901L
 #define BSON_FUNC __FUNCTION__
