@@ -45,50 +45,18 @@
 #endif
 
 
-/*
- * MONGOC_ENABLE_SSL_SECURE_TRANSPORT is set from configure to determine if we are
- * compiled with Native SSL support on Darwin
- */
-#define MONGOC_ENABLE_SSL_SECURE_TRANSPORT 0
-
-#if MONGOC_ENABLE_SSL_SECURE_TRANSPORT != 1
-#  undef MONGOC_ENABLE_SSL_SECURE_TRANSPORT
-#endif
-
-
-/*
- * MONGOC_ENABLE_CRYPTO_COMMON_CRYPTO is set from configure to determine if we are
- * compiled with Native Crypto support on Darwin
- */
-#define MONGOC_ENABLE_CRYPTO_COMMON_CRYPTO 0
-
-#if MONGOC_ENABLE_CRYPTO_COMMON_CRYPTO != 1
-#  undef MONGOC_ENABLE_CRYPTO_COMMON_CRYPTO
-#endif
-
-
 /*
  * MONGOC_ENABLE_SSL_OPENSSL is set from configure to determine if we are
  * compiled with OpenSSL support.
  */
+#ifndef MONGOC_ENABLE_SSL_SECURE_TRANSPORT
 #define MONGOC_ENABLE_SSL_OPENSSL 1
-
-#if MONGOC_ENABLE_SSL_OPENSSL != 1
-#  undef MONGOC_ENABLE_SSL_OPENSSL
 #endif
 
-
-/*
- * MONGOC_ENABLE_CRYPTO_LIBCRYPTO is set from configure to determine if we are
- * compiled with OpenSSL support.
- */
+#ifndef MONGOC_ENABLE_CRYPTO_COMMON_CRYPTO
 #define MONGOC_ENABLE_CRYPTO_LIBCRYPTO 1
-
-#if MONGOC_ENABLE_CRYPTO_LIBCRYPTO != 1
-#  undef MONGOC_ENABLE_CRYPTO_LIBCRYPTO
 #endif
 
-
 /*
  * MONGOC_ENABLE_SSL is set from configure to determine if we are
  * compiled with any SSL support.
